#
# NOTE: Not a script, to be included by scripts
#
USER=$(id -un)
BASEDIR=rundir/${TESTNAME}/
PORT=22222

mkdir -p ${BASEDIR}
rm -f ${BASEDIR}cokebank.db

# Template configuration (disables door and the coke machine)
cat << EOF > ${BASEDIR}cfg_server.conf
# AUTOGENERATED Test ${TESTNAME}
server_port ${PORT}
cokebank_database ${BASEDIR}cokebank.db
items_file ${BASEDIR}cfg_items.conf
door_serial_port /dev/null

coke_modbus_address 0.0.0.0
coke_modbus_port 502
test_mode no

disable_syslog yes
coke_dummy_mode yes
EOF

echo "# AUTOGENERATED Test ${TESTNAME}" > ${BASEDIR}cfg_items.conf
echo "pseudo	0	0	Test item" >> ${BASEDIR}cfg_items.conf

LOG() {
	echo "TEST ${TESTNAME}: "$*
}
FAIL() {
	echo "TEST ${TESTNAME} FAIL: "$*
	exit 1
}
TRY_COMMAND() {
	cmd="$*"
	echo ">> $cmd"
	if ! $cmd ; then
		FAIL "Command \`$cmd\` failed"
	fi
}

DISPENSE="../dispense -f /dev/null -H localhost -P ${PORT}"

LD_LIBRARY_PATH=.. ../dispsrv -f ${BASEDIR}cfg_server.conf --dont-daemonise -d 2 > ${BASEDIR}server.log 2>&1 &
server_pid=$!

cleanup() {
	if pidof dispsrv | grep ${server_pid} > /dev/null; then
		LOG "Killing ${server_pid}"
		kill ${server_pid}; true
	else
		LOG "Server already terminated"
	fi
}
trap cleanup EXIT

LOG "Server running on PID ${server_pid}"
sleep 1
# - Make sure that the server started
if ! (echo "" | nc localhost ${PORT}); then
	LOG "Server not responding on ${PORT}"
	LOG "Server log contents:"
	cat ${BASEDIR}server.log
	exit 1
fi

if [[ "x$USER" == "xroot" ]]; then
	FAIL "Running as root"
fi
# Ensure that the database doesn't already contain the current user
# - 1. Protects against running the test against the production database
# - 2. Allows adding the current user as an admin
if $DISPENSE acct "${USER}" 2> /dev/null; then
	FAIL "Database contains '$USER', are you running on production?"
fi
# Add the current user as an admin
sqlite3 "${BASEDIR}cokebank.db" "INSERT INTO accounts (acct_name,acct_is_admin,acct_uid) VALUES ('${USER}',1,1);"
